@@ -1,8 +1,10 @@
 context("format parsing")
 
-test_that("error when there is no formatting", {
-  expect_error(annotate_mf("./dog_test_plain.xlsx",
-                           orig = Task, new = Task_annotated))
+test_that("no annotations when there is no formatting", {
+  ogsprdsht <- readxl::read_excel("./dog_test_plain.xlsx")
+  annot <- annotate_mf("./dog_test_plain.xlsx",
+              orig = Task, new = Task_annotated)
+  expect_identical(ogsprdsht$Task,annot$Task_annotated)
 })
 
 test_that("error when spreadsheet has empty or NA values in the header row", {
